@@ -50,7 +50,10 @@ from .iotcontrol.enums import (
     TextFormat,
     DirectionStyle,
     ColorPickerStyle,
-    ControlName
+    ControlName,
+    ButtonStyle,
+    ButtonGroupStyle,
+    MenuStyle
 )
 from .iotcontrol.audio_visual_display import AudioVisualDisplay
 from .iotcontrol.chart import Chart, ChartLine
