@@ -28,13 +28,14 @@ import sys
 import shortuuid
 import zmq
 
-
-from .constants import CONNECTION_PUB_URL, MEMORY_REQ_URL, TASK_PULL
+from . import ip
+from .constants import CONNECTION_PUB_URL, TASK_MEMORY_PORT_OFFSET, TASK_PULL_PORT_OFFSET, TASK_CONN_PORT_OFFSET, TCP_URL
 from .action_station_services.task_service import TaskService
 from .action_station_services.timer_service import TimerService, make_timer_config
 from .action_station_services.as_servicel import make_test_config
 from .action_station_services.modbus_service import ModbusService, make_modbus_config
 from .action_station_services.clock_servicel import ClockService, make_clock_config
+from .action_station_services.ttn_service import TtnService, make_ttn_config
 from .load_config import CONTROL_INSTANCE_DICT, CONFIG_INSTANCE_DICT, decode_cfg64, encode_cfg64
 
 
@@ -120,7 +121,7 @@ class ActionStation(threading.Thread):
                         modified = True
                         logging.debug("Deleting layouts: %s, %s", control_type, control['controlID'])
                         try:
-                            self.device.controls_dict[key].del_configs_columnar()
+                            self.device.controls_dict[key].del_config()
                         except KeyError:
                             logging.debug("Error deleting layout: %s, %s", control_type, control['controlID'])
         return modified
@@ -138,7 +139,7 @@ class ActionStation(threading.Thread):
                         # load new config into control
                         logging.debug("Adding layouts: %s, %s", control_type, control['controlID'])
                         cfg = CONFIG_INSTANCE_DICT[control_type].from_dict(control)
-                        self.device.controls_dict[key].add_config_columnar(cfg)
+                        self.device.controls_dict[key].add_config(cfg)
                         modified = True
                         if key in added_control_ids:
                             # Add the next config to the control
@@ -220,11 +221,11 @@ class ActionStation(threading.Thread):
         self.tx_zmq_pub.send_multipart([b"COMMAND", json.dumps(msg_dict).encode()])
 
     def _start_control(self, t_object: dict):
-        if t_object['uuid'] in self.thread_dicts:
-            self.thread_dicts[t_object['uuid']].close()
+        if t_object["uuid"] in self.thread_dicts:
+            self.thread_dicts[t_object["uuid"]].close()
             time.sleep(0.1)
-        logging.debug("INIT TASK %s", t_object['uuid'])
-        self.thread_dicts[t_object['uuid']] = self.service_objects_defs[t_object['objectType']](self.device_id, self.zmq_service_uuid, t_object, self.context)
+        logging.debug("INIT TASK %s", t_object["uuid"])
+        self.thread_dicts[t_object['uuid']] = self.service_objects_defs[t_object['objectType']](self.device_id, self.local_port, t_object, self.context)
         return True
 
     def _list_command(self, data):
@@ -240,10 +241,10 @@ class ActionStation(threading.Thread):
         # TODO delete this for loop
         for j_object in self.configs.values():
             action_pair = {
-                "name": j_object['name'],
-                "uuid": j_object['uuid'],
-                "objectType": j_object['objectType'],
-                "revision": j_object.get('revision', 1)
+                "name": j_object.name,
+                "uuid": j_object.uuid,
+                "objectType": j_object.objectType,
+                "revision": j_object.revision
             }
             j_object_list.append(action_pair)
         result = {
@@ -254,13 +255,14 @@ class ActionStation(threading.Thread):
         return reply
 
     def _list_configs_command(self, data):
-        j_object_list = []
-        for j_object in self.configs.values():
-            if j_object['objectType'] == "CONFIG":
-                j_object_list.append(j_object)
+        config_list = []
+        for config in self.configs.values():
+            if config.objectType == "CONFIG":
+                config_list.append(config.dict())
+                logging.debug("Conf: %s", config.objectName)
         result = {
             'objectType': "LIST_RESULT",
-            'list': j_object_list
+            'list': config_list
         }
         reply = f"\t{self.device_id}\tACTN\tLIST_CONFIGS\t{json.dumps(result)}\n"
         return reply
@@ -356,7 +358,7 @@ class ActionStation(threading.Thread):
         self.device_id = device.device_id
         self.device = device
         self._json_filename = f"{self.device_id}_Actions.json"
-
+        self.local_port = 7654
         self.configured_services = {}
         self.configs = {}
         self.memory_tasks = {}
@@ -366,11 +368,16 @@ class ActionStation(threading.Thread):
         self.action_station_dict = self.load_action(self._json_filename)
         self.max_actions = max_actions
 
+        while ip.is_port_in_use("127.0.0.1", self.local_port):
+            # increment port until we find one that is free.
+            self.local_port += 1
+
         self.service_objects_defs = {
             'TASK': TaskService,
             'TMR': TimerService,
             'MDBS': ModbusService,
-            'CLK': ClockService
+            'CLK': ClockService,
+            'TTN': TtnService
         }
         self.thread_dicts = {}  # For the Instantiated control and task objects.
 
@@ -387,11 +394,13 @@ class ActionStation(threading.Thread):
         test_cfg = make_test_config(1)
         modbus_cfg = make_modbus_config(1)
         clock_cfg = make_clock_config(1)
-        self.configs[timer_cfg['uuid']] = timer_cfg
-        self.configs[test_cfg['uuid']] = test_cfg
-        self.configs[modbus_cfg['uuid']] = modbus_cfg
-        self.configs[clock_cfg['uuid']] = clock_cfg
-        self.zmq_service_uuid = "SRVC:" + shortuuid.uuid()
+        ttn_cfg = make_ttn_config(1)
+        self.configs[timer_cfg.uuid] = timer_cfg
+        self.configs[test_cfg.uuid] = test_cfg
+        self.configs[modbus_cfg.uuid] = modbus_cfg
+        self.configs[clock_cfg.uuid] = clock_cfg
+        self.configs[ttn_cfg.uuid] = ttn_cfg
+        # self.zmq_service_uuid = "SRVC:" + shortuuid.uuid()
         if not self.action_station_dict:
             self.zmq_connection_uuid = "ACTN:" + shortuuid.uuid()
             self.action_station_dict['actionStationID'] = self.zmq_connection_uuid
@@ -411,8 +420,7 @@ class ActionStation(threading.Thread):
     def run(self):
 
         self.zmq_service_pub = self.context.socket(zmq.PUB)
-
-        self.zmq_service_pub.bind(CONNECTION_PUB_URL.format(id=self.zmq_service_uuid))
+        self.zmq_service_pub.bind(TCP_URL.format(port=self.local_port + TASK_CONN_PORT_OFFSET))
 
         self.tx_zmq_pub = self.context.socket(zmq.PUB)
         self.tx_zmq_pub.bind(CONNECTION_PUB_URL.format(id=self.zmq_connection_uuid))
@@ -429,10 +437,10 @@ class ActionStation(threading.Thread):
 
         #  Socket to receive messages on
         task_receiver = self.context.socket(zmq.PULL)
-        task_receiver.bind(TASK_PULL.format(id=self.zmq_service_uuid))
+        task_receiver.bind(TCP_URL.format(port=self.local_port + TASK_PULL_PORT_OFFSET))
 
         memory_socket = self.context.socket(zmq.REP)
-        memory_socket.bind(MEMORY_REQ_URL.format(id=self.device_id))
+        memory_socket.bind(TCP_URL.format(port=self.local_port + TASK_MEMORY_PORT_OFFSET))
 
         poller = zmq.Poller()
         poller.register(self.device_zmq_sub, zmq.POLLIN)
@@ -470,7 +478,8 @@ class ActionStation(threading.Thread):
                 if msg.startswith(f"\t{self.device_id}\tACTN".encode()):
                     self._service_actn_commands(msg, msg_from)
                     continue
-                self.zmq_service_pub.send_multipart([msg, msg_from])
+                for sub_msg in msg.split(b'\n'):
+                    self.zmq_service_pub.send_multipart([sub_msg, msg_from])
 
             if task_receiver in socks:
                 msg_to, msg = task_receiver.recv_multipart()
