@@ -22,7 +22,9 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 CONNECTION_PUB_URL = "inproc://DASHIO_CONN_PUB_{id}"
-MEMORY_REQ_URL = "inproc://DASHIO_MEM_REQ_{id}"
-TASK_PULL = "inproc://DASHIO_TASK_PULL_{id}"
+TCP_URL = "tcp://127.0.0.1:{port}"
+TASK_CONN_PORT_OFFSET = 1
+TASK_PULL_PORT_OFFSET = 2
+TASK_MEMORY_PORT_OFFSET = 3
 
-BAD_CHARS = {ord(i): None for i in '\t\n'}
+BAD_CHARS = {ord(i): ' ' for i in '\t\n'}
