@@ -32,6 +32,7 @@ import shortuuid
 import zmq
 
 from .constants import CONNECTION_PUB_URL
+from .iotcontrol.enums import ConnectionState
 
 
 class DashControl():
@@ -131,9 +132,7 @@ class DashConnection(threading.Thread):
     """
     def _on_connect(self, client, userdata, flags, msg):
         if msg == 0:
-            self._connected = True
-            self._disconnected = False
-            self._connecting = False
+            self._connection_state = ConnectionState.CONNECTED
             for device_id in self._device_id_list:
                 control_topic = f"{self.username}/{device_id}/control"
                 self._dash_c.subscribe(control_topic, 0)
@@ -147,10 +146,8 @@ class DashConnection(threading.Thread):
 
     def _on_disconnect(self, client, userdata, msg):
         logging.debug("disconnecting reason  %s", msg)
-        self._connected = False
-        self._connecting = False
-        self._disconnected = True
-        self.disconnect_timeout = 1.0
+        self._connection_state = ConnectionState.DISCONNECTED
+        self._disconnect_timeout = 1.0
 
     def _on_message(self, client, obj, msg):
         data = str(msg.payload, "utf-8").strip()
@@ -174,7 +171,7 @@ class DashConnection(threading.Thread):
         if device.device_id not in self._device_id_list:
             self._device_id_list.append(device.device_id)
             device.register_connection(self)
-            if self._connected:
+            if self._connection_state == ConnectionState.CONNECTED:
                 control_topic = f"{self.username}/{device.device_id}/control"
                 self._dash_c.subscribe(control_topic, 0)
                 self._send_dash_announce()
@@ -248,9 +245,7 @@ class DashConnection(threading.Thread):
         threading.Thread.__init__(self, daemon=True)
 
         self.context = context or zmq.Context.instance()
-        self._connected = False
-        self._disconnected = True
-        self._connecting = True
+        self._connection_state = ConnectionState.DISCONNECTED
         self.zmq_connection_uuid = "DASH:" + shortuuid.uuid()
         self._b_zmq_connection_uuid = self.zmq_connection_uuid.encode('utf-8')
         self._device_id_list = []
@@ -286,12 +281,12 @@ class DashConnection(threading.Thread):
             self._dash_c.username_pw_set(username, password)
             try:
                 self._dash_c.connect(host, port)
-                self._connecting = True
-            except mqtt.socket.gaierror as error:
-                logging.debug("No connection to internet: %s", str(error))
+                self._connection_state = ConnectionState.CONNECTING
+            except (mqtt.socket.gaierror, ConnectionRefusedError) as error:
+                logging.debug("No connection to server: %s", str(error))
         # Start subscribe, with QoS level 0
         self.rx_zmq_sub = self.context.socket(zmq.SUB)
-        self.disconnect_timeout = 15.0
+        self._disconnect_timeout = 1.0
         self.start()
 
     def close(self):
@@ -353,18 +348,18 @@ class DashConnection(threading.Thread):
                     data_topic = f"{self.username}/{device_id}/announce"
                 else:
                     data_topic = f"{self.username}/{device_id}/data"
-                if self._connected and data_topic:
+                if self._connection_state == ConnectionState.CONNECTED and data_topic:
                     logging.debug("DASH TX:\n%s", data.decode().rstrip())
                     self._dash_c.publish(data_topic, data.decode())
-            if self._disconnected and not self._connecting:
-                self.disconnect_timeout = min(self.disconnect_timeout, 900)
-                time.sleep(self.disconnect_timeout)
+            if self._connection_state == ConnectionState.DISCONNECTED:
+                self._disconnect_timeout = min(self._disconnect_timeout, 900)
+                time.sleep(self._disconnect_timeout)
                 try:
                     self._dash_c.connect(self.host, self.port)
-                    self._connecting = True
-                except mqtt.socket.gaierror as error:
-                    logging.debug("No connection to internet: %s", str(error))
-                self.disconnect_timeout = self.disconnect_timeout * 2
+                    self._connection_state = ConnectionState.CONNECTING
+                except (mqtt.socket.gaierror, ConnectionRefusedError) as error:
+                    logging.debug("No connection to server: %s", str(error))
+                self._disconnect_timeout = self._disconnect_timeout * 2
 
         self._dash_c.loop_stop()
         self.tx_zmq_pub.close()
