@@ -60,6 +60,12 @@ class Device(threading.Thread):
     get_control(control_type: str, control_id: str):
         returns the instance of a controla leaded into the device.
 
+    remove_control(control_type, control_id) :
+        Removes the control from the device.
+
+    is_control_loaded(iot_control) :
+         Returns boolean if the control is loaded in the device.
+
     add_all_c64_controls(c64_dict: dict):
         Adds all controls defined in c64_dict into the device.
 
@@ -135,7 +141,7 @@ class Device(threading.Thread):
         reply = f"\t{self.device_id}\tNAME\t{self._device_name}\n"
         for value in self.controls_dict.values():
             try:
-                reply += value.get_state().format(device_id=self.device_id)
+                reply += value.get_state().replace("{device_id}", self.device_id)
             except (TypeError, KeyError):
                 pass
         return reply
@@ -179,7 +185,6 @@ class Device(threading.Thread):
                     dvvw_str += self._device_id_str + cfg
             else:
                 cfg_list = control.get_cfg(data)
-                #  logging.debug("CFG: %s", cfg_list)
                 for cfg in cfg_list:
                     reply += self._device_id_str + cfg
         reply += dvvw_str
@@ -194,7 +199,7 @@ class Device(threading.Thread):
         if not data:
             return
         if isinstance(data, str):
-            reply_send = data.format(device_id=self.device_id)
+            reply_send = data.replace("{device_id}", self.device_id)
         elif isinstance(data, list):
             reply_send = "\t" + "\t".join(data) + "\n"
         try:
@@ -207,28 +212,33 @@ class Device(threading.Thread):
         logging.debug("ANNOUNCE: %s", payload)
         self.tx_zmq_pub.send_multipart([b"DASH", payload.encode('utf-8')])
 
-    def is_control_loaded(self, control_type, control_id) -> bool:
+    def is_control_loaded(self, control_type, control_id: str) -> bool:
         """Is the control loaded in the device?"""
         key = f"{control_type}\t{control_id}"
         return key in self.controls_dict
 
-    def add_all_c64_controls(self, c64_dict):
+    def add_all_c64_controls(self, c64_dict: dict, column_no=1):
         """Loads all the controls in cfg_dict into the device.
 
         Parameters
         ----------
         c64_dict : Dict
             dictionary of the CFG loaded by decode_cfg from a CFG64 or json
+        column_no: Int From 1 to 3 (default 1).
+            The DashIO app reports the size of the screen in no of columns. You can load a seperate
+            config for each reported column number.
         """
+        if not 1 <= column_no <= 3:
+            column_no = 1
         for control_type, control_list in c64_dict.items():
             if isinstance(control_list, list):
                 for control in control_list:
                     key = f"{control_type}\t{control['controlID']}"
                     if self.is_control_loaded(control_type, control['controlID']):
                         cfg = CONFIG_INSTANCE_DICT[control_type].from_dict(control)
-                        self.controls_dict[key].add_config_columnar(cfg)
+                        self.controls_dict[key].add_config(cfg, column_no=column_no)
                     else:
-                        new_control = CONTROL_INSTANCE_DICT[control_type].from_cfg_dict(control)
+                        new_control = CONTROL_INSTANCE_DICT[control_type].from_cfg_dict(control, column_no=column_no)
                         self.add_control(new_control)
 
     def add_control(self, iot_control):
