@@ -34,7 +34,8 @@ class AudioVisualDisplay(Control):
         control_id: str,
         title="A Audio visual display",
         title_position=TitlePosition.BOTTOM,
-        control_position=None
+        control_position=None,
+        column_no=1
     ):
         """AudioVisualDisplay
         Set the URL for IoTDashboard to play the media pointed to by the URL
@@ -49,13 +50,17 @@ class AudioVisualDisplay(Control):
             The position of the control on a DeviceView, by default None
         title_position : TitlePosition, optional
             Position of the title when displayed on the iotdashboard app, by default None
+        column_no : int, optional default is 1. Must be 1..3
+            The Dash App reports its screen size in columns. column_no allows you to specify which column no to load into.
+            Each control can store three configs that define how the device looks for Dash apps installed on single column
+            phones or 2 column fold out phones or 3 column tablets.
         """
         super().__init__("AVD", control_id)
-        self._cfg_columnar.append(ControlConfig(control_id, title, control_position, title_position))
+        self._app_columns_cfg[str(column_no)].append(ControlConfig(control_id, title, control_position, title_position))
         self.url = ""
 
     @classmethod
-    def from_cfg_dict(cls, cfg_dict: dict):
+    def from_cfg_dict(cls, cfg_dict: dict, column_no=1):
         """Instatiates Button from cfg dictionary
 
         Parameters
@@ -71,7 +76,8 @@ class AudioVisualDisplay(Control):
             cfg_dict["controlID"],
             cfg_dict["title"],
             _get_title_position(cfg_dict["titlePosition"]),
-            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"])
+            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"]),
+            column_no
         )
         tmp_cls.parent_id = cfg_dict["parentID"]
         return tmp_cls
