@@ -22,8 +22,8 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 from ..constants import BAD_CHARS
-from .control import Control, ControlPosition, ControlConfig, _get_color, _get_icon, _get_title_position
-from .enums import ButtonState, Color, Icon, TitlePosition
+from .control import Control, ControlPosition, ControlConfig, _get_color, _get_icon, _get_title_position, _get_button_style, _get_color_str
+from .enums import ButtonState, Color, Icon, TitlePosition, ButtonStyle
 
 
 class ButtonConfig(ControlConfig):
@@ -34,6 +34,7 @@ class ButtonConfig(ControlConfig):
         title: str,
         title_position: TitlePosition,
         button_enabled: bool,
+        style: ButtonStyle,
         icon_name: Icon,
         on_color: Color,
         off_color: Color,
@@ -44,8 +45,9 @@ class ButtonConfig(ControlConfig):
         self.cfg["text"] = text.translate(BAD_CHARS)
         self.cfg["iconName"] = icon_name.value
         self.cfg["buttonEnabled"] = button_enabled
-        self.cfg["onColor"] = str(on_color.value)
-        self.cfg["offColor"] = str(off_color.value)
+        self.cfg["style"] = str(style.value)
+        self.cfg["onColor"] = _get_color_str(on_color)
+        self.cfg["offColor"] = _get_color_str(off_color)
 
     @classmethod
     def from_dict(cls, cfg_dict: dict):
@@ -62,13 +64,14 @@ class ButtonConfig(ControlConfig):
         """
         tmp_cls = cls(
             cfg_dict["controlID"],
-            cfg_dict["title"],
-            _get_title_position(cfg_dict["titlePosition"]),
-            cfg_dict["buttonEnabled"],
-            _get_icon(cfg_dict["iconName"]),
-            _get_color(cfg_dict["onColor"]),
-            _get_color(cfg_dict["offColor"]),
-            cfg_dict["text"],
+            cfg_dict.get("title", ''),
+            _get_title_position(cfg_dict.get("titlePosition", 'bottom')),
+            cfg_dict.get("buttonEnabled", True),
+            _get_button_style(cfg_dict.get("style", 'basic')),
+            _get_icon(cfg_dict.get("iconName", 'none')),
+            _get_color(cfg_dict.get("onColor", 'blue')),
+            _get_color(cfg_dict.get("offColor", 'red')),
+            cfg_dict.get("text", ""),
             ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"])
         )
         tmp_cls.parent_id = cfg_dict["parentID"]
@@ -90,6 +93,8 @@ class Button(Control):
         Can be TitlePosition.BOTTOM, TitlePosition.TOP, TitlePosition.OFF
     button_enabled : boolean
         True allows the app to send button events. False disables button pushes
+    stype : ButtonStyle
+        The style of the button. Options are ButtonStyle.BASIC, ButtonStyle.HIGHLIGHT
     icon_name : Icon
         Set the icon for the button
     off_color : Color
@@ -98,6 +103,10 @@ class Button(Control):
         Set the on color
     control_position : ControlPosition
         Set the size and position of the button on a DeviceView.
+    column_no : int, optional default is 1. Must be 1..3
+        The Dash App reports its screen size in columns. column_no allows you to specify which column no to load into.
+        Each control can store three configs that define how the device looks for Dash apps installed on single column
+        phones or 2 column fold out phones or 3 column tablets.
 
     Methods
     -------
@@ -125,19 +134,22 @@ class Button(Control):
         title="A Button",
         title_position=TitlePosition.BOTTOM,
         button_enabled=True,
+        style=ButtonStyle.BASIC,
         icon_name=Icon.NONE,
         on_color=Color.BLUE,
         off_color=Color.RED,
         text="",
-        control_position: ControlPosition = None
+        control_position: ControlPosition = None,
+        column_no=1
     ):
         super().__init__("BTTN", control_id)
-        self._cfg_columnar.append(
+        self._app_columns_cfg[str(column_no)].append(
             ButtonConfig(
                 control_id,
                 title,
                 title_position,
                 button_enabled,
+                style,
                 icon_name,
                 on_color,
                 off_color,
@@ -150,7 +162,7 @@ class Button(Control):
         self._icon_name = icon_name
 
     @classmethod
-    def from_cfg_dict(cls, cfg_dict: dict):
+    def from_cfg_dict(cls, cfg_dict: dict, column_no=1):
         """Instatiates Button from cfg dictionary
 
         Parameters
@@ -167,11 +179,13 @@ class Button(Control):
             cfg_dict["title"],
             _get_title_position(cfg_dict["titlePosition"]),
             cfg_dict["buttonEnabled"],
+            _get_button_style(cfg_dict.get("style", 'basic')),
             _get_icon(cfg_dict["iconName"]),
             _get_color(cfg_dict["onColor"]),
             _get_color(cfg_dict["offColor"]),
             cfg_dict["text"],
-            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"])
+            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"]),
+            column_no
         )
         tmp_cls.parent_id = cfg_dict["parentID"]
         return tmp_cls
