@@ -22,7 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 from ..constants import BAD_CHARS
-from .control import Control, ControlPosition, ControlConfig, _get_color, _get_title_position, _get_direction_style, _get_precision
+from .control import Control, ControlPosition, ControlConfig, _get_color, _get_title_position, _get_direction_style, _get_precision, _get_color_str
 from .enums import Color, DirectionStyle, Precision, TitlePosition
 
 
@@ -42,7 +42,7 @@ class DirectionConfig(ControlConfig):
     ) -> None:
         super().__init__(control_id, title, control_position, title_position)
         self.cfg["style"] = str(style.value)
-        self.cfg["pointerColor"] = str(pointer_color.value)
+        self.cfg["pointerColor"] = _get_color_str(pointer_color)
         self.cfg["units"] = units
         self.cfg["precision"] = precision.value
         self.cfg["calAngle"] = calibration_angle
@@ -78,17 +78,11 @@ class DirectionConfig(ControlConfig):
 class Direction(Control):
     """Direction control"""
 
-    def add_config_columnar(self, config: DirectionConfig):
+    def add_config(self, config: DirectionConfig, column_no=1):
         if isinstance(config, DirectionConfig):
             config.cfg["calAngle"] = self.cal_angle
             config.cfg["ControlID"] = self.control_id
-            self._cfg_columnar.append(config)
-
-    def add_config_full_page(self, config: DirectionConfig):
-        if isinstance(config, DirectionConfig):
-            config.cfg["calAngle"] = self.cal_angle
-            config.cfg["ControlID"] = self.control_id
-            self._cfg_full_page.append(config)
+            self._app_columns_cfg[str(column_no)]
 
     def __init__(
         self,
@@ -100,7 +94,8 @@ class Direction(Control):
         units="",
         precision=Precision.OFF,
         calibration_angle=0,
-        control_position=None
+        control_position=None,
+        column_no=1
     ):
         """Direction Control
 
@@ -124,9 +119,13 @@ class Direction(Control):
             Precision of the value displayed, by default Precision.OFF
         calibration_angle : int, optional
             Calibration angle offset, by default 0
+        column_no : int, optional default is 1. Must be 1..3
+            The Dash App reports its screen size in columns. column_no allows you to specify which column no to load into.
+            Each control can store three configs that define how the device looks for Dash apps installed on single column
+            phones or 2 column fold out phones or 3 column tablets.
         """
         super().__init__("DIR", control_id)
-        self._cfg_columnar.append(
+        self._app_columns_cfg[str(column_no)].append(
             DirectionConfig(
                 control_id,
                 title,
@@ -149,7 +148,7 @@ class Direction(Control):
         return self._cal_angle
 
     @classmethod
-    def from_cfg_dict(cls, cfg_dict: dict):
+    def from_cfg_dict(cls, cfg_dict: dict, column_no=1):
         """Instatiates Direction from cfg dictionary
 
         Parameters
@@ -170,7 +169,8 @@ class Direction(Control):
             cfg_dict["units"],
             _get_precision(cfg_dict["precision"]),
             cfg_dict["calAngle"],
-            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"])
+            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"]),
+            column_no
         )
         tmp_cls.parent_id = cfg_dict["parentID"]
         return tmp_cls
