@@ -24,6 +24,15 @@ SOFTWARE.
 from enum import Enum
 
 
+class ConnectionState(Enum):
+    """
+    Used Internally for MQTT and DashConntections
+    """
+    CONNECTED = 0
+    CONNECTING = 1
+    DISCONNECTED = 2
+
+
 class ControlName(Enum):
     """
     All the control names
@@ -52,7 +61,6 @@ class Icon(Enum):
     """
     NONE = "None"
     DOT = "Dot"
-    PAD = "Pad"
     UP = "Up"
     DOWN = "Down"
     LEFT = "Left"
@@ -134,6 +142,24 @@ class SoundName(Enum):
     BOING = "Boing"
 
 
+class ButtonStyle(Enum):
+    """Button Styles"""
+    BASIC = "basic"
+    HIGHLIGHT = "highlight"
+
+
+class MenuStyle(Enum):
+    """Menu Styles"""
+    BASIC = "basic"
+    HIGHLIGHT = "highlight"
+
+
+class ButtonGroupStyle(Enum):
+    """Button Group Styles"""
+    BASIC = "basic"
+    HIGHLIGHT = "highlight"
+
+
 class DeviceViewStyle(Enum):
     """DeciveView Styles"""
     BASIC = "BASIC"
@@ -204,6 +230,7 @@ class TextFormat(Enum):
     DATETIME = "DATETIME"
     DATELONG = "DTLONG"
     INTERVAL = "INTVL"
+    LOG = "LOG"
 
 
 class TextAlignment(Enum):
