@@ -30,6 +30,7 @@ from .enums import Color, TitlePosition
 from .ring_buffer import RingBuffer
 from .event import Event
 
+
 class EventData:
     """Event log data point
     """
@@ -81,12 +82,15 @@ class EventLog(Control):
     """EventLog control
     """
 
-    def __init__(self,
-                 control_id: str,
-                 title="An Event Log",
-                 title_position=TitlePosition.BOTTOM,
-                 control_position=None,
-                 max_log_entries=100):
+    def __init__(
+        self,
+        control_id: str,
+        title="An Event Log",
+        title_position=TitlePosition.BOTTOM,
+        control_position=None,
+        max_log_entries=100,
+        column_no=1
+    ):
         """An EventLog control
 
         Parameters
@@ -103,16 +107,20 @@ class EventLog(Control):
         max_log_entries : int, optional
             The EventLog usues a ring buffer for data entries this dfines the number of
             entries before over wrting older entires, by default 100
+        column_no : int, optional default is 1. Must be 1..3
+            The Dash App reports its screen size in columns. column_no allows you to specify which column no to load into.
+            Each control can store three configs that define how the device looks for Dash apps installed on single column
+            phones or 2 column fold out phones or 3 column tablets.
         """
         super().__init__("LOG", control_id)
-        self._cfg_columnar.append(ControlConfig(control_id, title, control_position, title_position))
+        self._app_columns_cfg[str(column_no)].append(ControlConfig(control_id, title, control_position, title_position))
 
         self._message_rx_event = Event()
         self._message_rx_event += self._get_log_from_timestamp
         self.log = RingBuffer(max_log_entries)
 
     @classmethod
-    def from_cfg_dict(cls, cfg_dict: dict):
+    def from_cfg_dict(cls, cfg_dict: dict, column_no=1):
         """Instatiates Menu from cfg dictionary
 
         Parameters
@@ -128,7 +136,8 @@ class EventLog(Control):
             cfg_dict["controlID"],
             cfg_dict["title"],
             _get_title_position(cfg_dict["titlePosition"]),
-            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"])
+            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"]),
+            column_no
         )
         tmp_cls.parent_id = cfg_dict["parentID"]
         return tmp_cls
@@ -147,7 +156,8 @@ class EventLog(Control):
                 data_str += "\t" + log.to_json()
                 has_data = True
         if has_data:
-            return data_str
+            data_str += "\n"
+        return data_str
 
     def add_event_data(self, data: EventData):
         """Add a data point to the log and send it to any connected iotdashboard app
@@ -161,7 +171,10 @@ class EventLog(Control):
             self.log.append(data)
             self.state_str = self._control_hdr_str + str(data)
 
-    def send_data(self):
+    def send_event(self, event: EventData):
+        self.state_str = self._control_hdr_str + str(event)
+
+    def send_latest_data(self):
         """Send the latest log entry to any connected iotdashboard app.
         """
         if self.log:
