@@ -21,7 +21,7 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
-from .control import Control, ControlPosition, ControlConfig, _get_color, _get_title_position, _get_knob_style
+from .control import Control, ControlPosition, ControlConfig, _get_color, _get_title_position, _get_knob_style, _get_color_str
 from .enums import Color, KnobStyle, TitlePosition
 
 
@@ -51,8 +51,8 @@ class KnobConfig(ControlConfig):
         self.cfg["showMinMax"] = show_min_max
         self.cfg["sendOnlyOnRelease"] = send_only_on_release
         self.cfg["dialFollowsKnob"] = dial_follows_knob
-        self.cfg["dialColor"] = str(dial_color.value)
-        self.cfg["knobColor"] = str(knob_color.value)
+        self.cfg["dialColor"] = _get_color_str(dial_color)
+        self.cfg["knobColor"] = _get_color_str(knob_color)
 
     @classmethod
     def from_dict(cls, cfg_dict: dict):
@@ -90,21 +90,13 @@ class Knob(Control):
     """A Knob control
     """
 
-    def add_config_columnar(self, config: KnobConfig):
+    def add_config_columnar(self, config: KnobConfig, column_no=1):
         if isinstance(config, KnobConfig):
             config.cfg["min"] = self.dial_min
             config.cfg["max"] = self.dial_max
             config.cfg["redValue"] = self.red_value
             config.cfg["ControlID"] = self.control_id
-            self._cfg_columnar.append(config)
-
-    def add_config_full_page(self, config: KnobConfig):
-        if isinstance(config, KnobConfig):
-            config.cfg["min"] = self.dial_min
-            config.cfg["max"] = self.dial_max
-            config.cfg["redValue"] = self.red_value
-            config.cfg["ControlID"] = self.control_id
-            self._cfg_columnar.append(config)
+            self._app_columns_cfg[str(column_no)]
 
     def __init__(
         self,
@@ -120,7 +112,8 @@ class Knob(Control):
         dial_follows_knob=False,
         dial_color=Color.BLUE,
         knob_color=Color.RED,
-        control_position=None
+        control_position=None,
+        column_no=1
     ):
         """A Knob control is a control with a dial and knob.
 
@@ -152,9 +145,13 @@ class Knob(Control):
             Color of the Knob, by default Color.RED
         control_position : ControlPosition, optional
             The position of the control on a DeviceView, by default None
+        column_no : int, optional default is 1. Must be 1..3
+            The Dash App reports its screen size in columns. column_no allows you to specify which column no to load into.
+            Each control can store three configs that define how the device looks for Dash apps installed on single column
+            phones or 2 column fold out phones or 3 column tablets.
         """
         super().__init__("KNOB", control_id)
-        self._cfg_columnar.append(
+        self._app_columns_cfg[str(column_no)].append(
             KnobConfig(
                 control_id,
                 title,
@@ -199,7 +196,7 @@ class Knob(Control):
         return self._red_value
 
     @classmethod
-    def from_cfg_dict(cls, cfg_dict: dict):
+    def from_cfg_dict(cls, cfg_dict: dict, column_no=1):
         """Instatiates Knob from cfg dictionary
 
         Parameters
@@ -224,7 +221,8 @@ class Knob(Control):
             cfg_dict["dialFollowsKnob"],
             _get_color(cfg_dict["dialColor"]),
             _get_color(cfg_dict["knobColor"]),
-            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"])
+            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"]),
+            column_no
         )
         tmp_cls.parent_id = cfg_dict["parentID"]
         return tmp_cls
