@@ -21,7 +21,7 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
-from .control import Control, ControlPosition, ControlConfig, _get_color, _get_title_position, _get_label_style
+from .control import Control, ControlPosition, ControlConfig, _get_color, _get_title_position, _get_label_style, _get_color_str
 from .enums import Color, LabelStyle, TitlePosition
 
 
@@ -38,7 +38,7 @@ class LabelConfig(ControlConfig):
     ) -> None:
         super().__init__(control_id, title, control_position, title_position)
         self.cfg["style"] = style.value
-        self.cfg["color"] = str(color.value)
+        self.cfg["color"] = _get_color_str(color)
 
     @classmethod
     def from_dict(cls, cfg_dict: dict):
@@ -76,6 +76,7 @@ class Label(Control):
         color=Color.WHITE,
         style=LabelStyle.BASIC,
         control_position=None,
+        column_no=1
     ):
         """Label
 
@@ -93,6 +94,10 @@ class Label(Control):
             Color of the label, by default Color.WHITE
         style : LabelStyle, optional
             Style of label to be displayed, by default LabelStyle.BASIC
+        column_no : int, optional default is 1. Must be 1..3
+            The Dash App reports its screen size in columns. column_no allows you to specify which column no to load into.
+            Each control can store three configs that define how the device looks for Dash apps installed on single column
+            phones or 2 column fold out phones or 3 column tablets.
         """
         super().__init__("LBL", control_id)
         control_config = LabelConfig(
@@ -103,11 +108,11 @@ class Label(Control):
             style,
             control_position
         )
-        self._cfg_columnar.append(control_config)
+        self._app_columns_cfg[str(column_no)].append(control_config)
         self._state_str = ""
 
     @classmethod
-    def from_cfg_dict(cls, cfg_dict: dict):
+    def from_cfg_dict(cls, cfg_dict: dict, column_no=1):
         """Instatiates a label from cfg dictionary
 
         Parameters
@@ -125,7 +130,8 @@ class Label(Control):
             _get_title_position(cfg_dict["titlePosition"]),
             _get_color(cfg_dict["color"]),
             _get_label_style(cfg_dict["style"]),
-            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"])
+            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"]),
+            column_no
         )
         tmp_cls.parent_id = cfg_dict["parentID"]
         return tmp_cls
