@@ -30,7 +30,14 @@ class Selector(Control):
     """A Selector control
     """
 
-    def __init__(self, control_id: str, title="A Selector", title_position=TitlePosition.BOTTOM, control_position=None):
+    def __init__(
+        self,
+        control_id: str,
+        title="A Selector",
+        title_position=TitlePosition.BOTTOM,
+        control_position=None,
+        column_no=1
+    ):
         """A Selector control
 
         Parameters
@@ -43,9 +50,13 @@ class Selector(Control):
             The position of the control on a DeviceView, by default None
         title_position : TitlePosition, optional
             Position of the title when displayed on the iotdashboard app, by default None
+        column_no : int, optional default is 1. Must be 1..3
+            The Dash App reports its screen size in columns. column_no allows you to specify which column no to load into.
+            Each control can store three configs that define how the device looks for Dash apps installed on single column
+            phones or 2 column fold out phones or 3 column tablets.
         """
         super().__init__("SLCTR", control_id)
-        self._cfg_columnar.append(
+        self._app_columns_cfg[str(column_no)].append(
             ControlConfig(
                 control_id,
                 title,
@@ -57,7 +68,7 @@ class Selector(Control):
         self.selection_list = []
 
     @classmethod
-    def from_cfg_dict(cls, cfg_dict: dict):
+    def from_cfg_dict(cls, cfg_dict: dict, column_no=1):
         """Instatiates Selector from cfg dictionary
 
         Parameters
@@ -73,7 +84,8 @@ class Selector(Control):
             cfg_dict["controlID"],
             cfg_dict["title"],
             _get_title_position(cfg_dict["titlePosition"]),
-            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"])
+            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"]),
+            column_no
         )
         tmp_cls.parent_id = cfg_dict["parentID"]
         return tmp_cls
@@ -94,6 +106,21 @@ class Selector(Control):
         """
         self.selection_list.append(text.translate(BAD_CHARS))
 
+    def send_selection(self, position=None):
+        """Sends the current selection list
+
+        Parameters
+        ----------
+        position : int
+            Set the position to send (Optional).
+        """
+        if position is not None:
+            self._position = position
+        slctr_str = self._control_hdr_str + f"{self._position}\t"
+        slctr_str += "\t".join(map(str, self.selection_list))
+        slctr_str += "\n"
+        self.state_str = slctr_str
+
     def set_selected(self, selected_text: str):
         """Set the selector to the selected text
 
