@@ -22,9 +22,15 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 from ..constants import BAD_CHARS
-from .control import Control, ControlPosition, ControlConfig, _get_title_position, _get_text_align, _get_text_format, _get_precision, _get_keyboard_type
-from .enums import (Keyboard, Precision, TextAlignment, TextFormat,
-                    TitlePosition)
+from .control import Control, ControlPosition, ControlConfig, _get_title_position, _get_text_align, _get_text_format, _get_precision, _get_keyboard_type, _get_color_str
+from .enums import (
+    Keyboard,
+    Precision,
+    TextAlignment,
+    TextFormat,
+    Color,
+    TitlePosition
+)
 
 
 class TextBoxConfig(ControlConfig):
@@ -99,6 +105,7 @@ class TextBox(Control):
         keyboard_type=Keyboard.ALL,
         close_keyboard_on_send=True,
         control_position=None,
+        column_no=1
     ):
         """A TextBox control
 
@@ -126,9 +133,13 @@ class TextBox(Control):
             Keyboard type for the textbox, by default Keyboard.ALL
         close_keyboard_on_send : bool, optional
             Set to True to close keyboard on close, by default True
+        column_no : int, optional default is 1. Must be 1..3
+            The Dash App reports its screen size in columns. column_no allows you to specify which column no to load into.
+            Each control can store three configs that define how the device looks for Dash apps installed on single column
+            phones or 2 column fold out phones or 3 column tablets.
         """
         super().__init__("TEXT", control_id)
-        self._cfg_columnar.append(
+        self._app_columns_cfg[str(column_no)].append(
             TextBoxConfig(
                 control_id,
                 title,
@@ -143,13 +154,14 @@ class TextBox(Control):
                 control_position
             )
         )
+        self._color = Color.WHITE
         self.text = text.translate(BAD_CHARS)
 
     def get_state(self):
         return self._control_hdr_str + f"{self.text}\n"
 
     @classmethod
-    def from_cfg_dict(cls, cfg_dict: dict):
+    def from_cfg_dict(cls, cfg_dict: dict, column_no=1):
         """Instatiates TextBox from cfg dictionary
 
         Parameters
@@ -172,7 +184,8 @@ class TextBox(Control):
             _get_precision(cfg_dict["precision"]),
             _get_keyboard_type(cfg_dict["kbdType"]),
             cfg_dict["closeKbdOnSend"],
-            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"])
+            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"]),
+            column_no
         )
         tmp_cls.parent_id = cfg_dict["parentID"]
         return tmp_cls
@@ -192,4 +205,20 @@ class TextBox(Control):
     def text(self, val: str):
         _val = val.translate(BAD_CHARS)
         self._text = _val
-        self.state_str = self._control_hdr_str + f"{_val}\n"
+        color = _get_color_str(self._color)
+        self.state_str = self._control_hdr_str + f"{_val}\t{color}\n"
+
+    @property
+    def color(self):
+        """TextBox Color
+
+        Returns
+        -------
+        Text
+            Text Color
+        """
+        return self._color
+
+    @color.setter
+    def color(self, val):
+        self._color = val
