@@ -32,7 +32,7 @@ from .iotcontrol import (
     ButtonGroup, ButtonGroupConfig,
     Button, ButtonConfig,
     TextBox, TextBoxConfig,
-    Graph, GraphConfig,
+    Chart, ChartConfig,
     Dial, DialConfig,
     ColorPicker, ColorPickerConfig,
     TimeGraph, TimeGraphConfig,
@@ -51,7 +51,7 @@ CONTROL_INSTANCE_DICT = {
     "BTGP": ButtonGroup,
     "BTTN": Button,
     "TEXT": TextBox,
-    "GRPH": Graph,
+    "CHRT": Chart,
     "DIAL": Dial,
     "CLR": ColorPicker,
     "TGRPH": TimeGraph,
@@ -70,7 +70,7 @@ CONFIG_INSTANCE_DICT = {
     "BTGP": ButtonGroupConfig,
     "BTTN": ButtonConfig,
     "TEXT": TextBoxConfig,
-    "GRPH": GraphConfig,
+    "CHRT": ChartConfig,
     "DIAL": DialConfig,
     "CLR": ColorPickerConfig,
     "TGRPH": TimeGraphConfig,
