@@ -60,11 +60,6 @@ class TCPConnection(threading.Thread):
             self.local_device_id_list.append(device.device_id)
             self.z_conf.add_device(device.device_id)
 
-    @staticmethod
-    def _is_port_in_use(ip_address, port):
-        with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as port_s:
-            return port_s.connect_ex((ip_address, port)) == 0
-
     def __init__(self, ip_address="*", port=5650, use_zero_conf=True, context: zmq.Context = None):
         """TCP Connection
 
@@ -87,14 +82,14 @@ class TCPConnection(threading.Thread):
         self.use_zeroconf = use_zero_conf
 
         if ip_address == "*":
-            self.local_ip = ip.get_local_ip_address()
+            self.local_ip = ip.get_local_ip_v4_address()
         else:
             self.local_ip = ip_address
         self.local_port = port
-        while self._is_port_in_use(self.local_ip, self.local_port) and use_zero_conf:
+        while ip.is_port_in_use(self.local_ip, self.local_port) and use_zero_conf:
             # increment port until we find one that is free.
             self.local_port += 1
-        self.ext_url = "tcp://" + self.local_ip + ":" + str(self.local_port)
+        self.ext_url = "tcp://*:" + str(self.local_port)
 
         self.socket_ids = []
         self.local_device_id_list = []
@@ -125,19 +120,19 @@ class TCPConnection(threading.Thread):
 
     def _connect_remote_device(self, msg: dict):
         """Connect to remote device"""
-        ip_address = msg['address']
+        server = msg['server']
         port = msg['port']
-        url = f"tcp://{ip_address}:{port}"
+        url = f"tcp://{server}:{port}"
         self.tcpsocket.connect(url)
         socket_id = self.tcpsocket.getsockopt(zmq.IDENTITY)
-        ip_b = ip_address + ':' + port
+        ip_b = server + ':' + port
         if ip_b not in self.tcp_ip_2_id_dict:
             try:
                 logging.debug("Sending WHO to ID: %s", socket_id.hex())
                 self.tcpsocket.send(socket_id, zmq.SNDMORE)
                 self.tcpsocket.send_string('\tWHO\n')
-                self.tcp_id_2_ip_dict[socket_id] = ip_address + ':' + port
-                self.tcp_ip_2_id_dict[ip_address + ':' + port] = socket_id
+                self.tcp_id_2_ip_dict[socket_id] = ip_b
+                self.tcp_ip_2_id_dict[ip_b] = socket_id
             except zmq.error.ZMQError:
                 logging.debug("Sending TX Error.")
                 self.tcpsocket.send(b'')
@@ -157,9 +152,9 @@ class TCPConnection(threading.Thread):
     def _send_remote_device(self, r_device_id, msg):
         if r_device_id in self.remote_device_id_msg_dict:
             remote = self.remote_device_id_msg_dict[r_device_id]
-            ip_address = remote['address']
+            server = msg['server']
             port = remote['port']
-            url = f"tcp://{ip_address}:{port}"
+            url = f"tcp://{server}:{port}"
             self.tcpsocket.connect(url)
             socket_id = self.tcpsocket.getsockopt(zmq.IDENTITY)
             self.tcpsocket.send(socket_id, zmq.SNDMORE)
@@ -228,7 +223,7 @@ class TCPConnection(threading.Thread):
     def _service_device_messaging(self):
 
         def _zmq_tcp_send(tcp_id, data: bytearray):
-            logging.debug("TCP TX:\n%s", data.decode().rstrip())
+            logging.debug("TCP TX %s:\n%s", tcp_id.hex(), data.decode().rstrip())
             try:
                 self.tcpsocket.send(tcp_id, zmq.SNDMORE)
                 self.tcpsocket.send(data, zmq.NOBLOCK)
@@ -268,7 +263,8 @@ class TCPConnection(threading.Thread):
         if message:
             logging.debug("TCP RX: %s\n%s", tcp_id.hex(), message.decode().rstrip())
             msg_from = self.b_zmq_connection_uuid + b":" + tcp_id
-            tx_zmq_pub.send_multipart([message, msg_from])
+            for sub_msg in message.split(b'\n'):
+                tx_zmq_pub.send_multipart([sub_msg, msg_from])
         else:
             if tcp_id in self.socket_ids:
                 logging.debug("Removed Socket ID: %s", tcp_id.hex())
@@ -276,7 +272,6 @@ class TCPConnection(threading.Thread):
 
     def run(self):
         self.tcpsocket = self.context.socket(zmq.STREAM)
-
         self.rx_zmq_sub = self.context.socket(zmq.SUB)
         # Subscribe on ALL, COMMAND, and my zmq_connection_uuid
         self.rx_zmq_sub.setsockopt_string(zmq.SUBSCRIBE, "ALL")
